@@ -15,7 +15,6 @@ use libc::{c_int, c_void, gid_t, kill, size_t, uid_t};
 
 use crate::{DiskUsage, Pid, ProcessExt, ProcessStatus, Signal};
 
-use crate::sys::ffi;
 use crate::sys::process::ThreadStatus;
 use crate::sys::system::Wrap;
 
@@ -32,8 +31,6 @@ pub struct Process {
     pub(crate) root: PathBuf,
     pub(crate) memory: u64,
     pub(crate) virtual_memory: u64,
-    utime: u64,
-    stime: u64,
     old_utime: u64,
     old_stime: u64,
     start_time: u64,
@@ -69,8 +66,6 @@ impl Process {
             memory: 0,
             virtual_memory: 0,
             cpu_usage: 0.,
-            utime: 0,
-            stime: 0,
             old_utime: 0,
             old_stime: 0,
             updated: true,
@@ -110,8 +105,6 @@ impl Process {
             memory: 0,
             virtual_memory: 0,
             cpu_usage: 0.,
-            utime: 0,
-            stime: 0,
             old_utime: 0,
             old_stime: 0,
             updated: true,
@@ -142,8 +135,6 @@ impl ProcessExt for Process {
             memory: 0,
             virtual_memory: 0,
             cpu_usage: 0.,
-            utime: 0,
-            stime: 0,
             old_utime: 0,
             old_stime: 0,
             updated: true,
@@ -594,8 +585,14 @@ fn update_proc_disk_activity(p: &mut Process) {
     p.old_read_bytes = p.read_bytes;
     p.old_written_bytes = p.written_bytes;
 
-    let mut pidrusage = MaybeUninit::<ffi::RUsageInfoV2>::uninit();
-    let retval = unsafe { ffi::proc_pid_rusage(p.pid() as c_int, 2, pidrusage.as_mut_ptr() as _) };
+    let mut pidrusage = MaybeUninit::<libc::rusage_info_v2>::uninit();
+    let retval = unsafe {
+        libc::proc_pid_rusage(
+            p.pid() as c_int,
+            libc::RUSAGE_INFO_V2,
+            pidrusage.as_mut_ptr() as _,
+        )
+    };
 
     if retval < 0 {
         sysinfo_debug!("proc_pid_rusage failed: {:?}", retval);
