@@ -14,7 +14,7 @@ pub(crate) mod ios;
 #[cfg(target_os = "ios")]
 pub(crate) use self::ios as inner;
 
-#[cfg(any(target_os = "ios", feature = "apple-app-store"))]
+#[cfg(any(target_os = "ios", feature = "apple-sandbox"))]
 pub(crate) mod app_store;
 
 pub mod component;
